@@ -1035,6 +1035,11 @@ _Tool = [
     dict(path='/tool/code_deck_import_task/list', method='get', resource=view.CodeDeckImportTaskList()),
 
     dict(path='/tool/get_number_analytic/{number}', method='get', resource=view.NumberAnalyticsGet()),
+    dict(path='/tool/check_lerg_db/{number}', method='post', resource=view.CheckLergDb()),
+    dict(path='/tool/check_dnc/{number}', method='post', resource=view.CheckDnc()),
+    dict(path='/tool/check_dno/{number}', method='post', resource=view.CheckDno()),
+    dict(path='/tool/check_youmail/{number}', method='post', resource=view.CheckYoumail()),
+    dict(path='/tool/check_ftc/{number}', method='post', resource=view.CheckFtc()),
 
 ]
 _Trunk = [
